Changelog
=========


(unreleased)
------------

Fix
~~~
- Bug in user panel. [hiddify]

Other
~~~~~
- Update. [hiddify]


0.9.94 (2023-02-27)
-------------------
- Release: version 0.9.94 🚀 [hiddify]
- Update. [hiddify]
- Update stash and shadowlink. [hiddify]


0.9.93 (2023-02-27)
-------------------
- Release: version 0.9.93 🚀 [hiddify]
- Fix bug when user max usage is zero. [hiddify]
- Add parent_domains to cli. [hiddify]


0.9.92 (2023-02-27)
-------------------
- Release: version 0.9.92 🚀 [hiddify]
- Fix expirydate issue. [hiddify]


0.9.91 (2023-02-26)
-------------------
- Release: version 0.9.91 🚀 [hiddify]
- Fix bool config. [hiddify]


0.9.90 (2023-02-26)
-------------------
- Release: version 0.9.90 🚀 [hiddify]
- Fix last online. [hiddify]


0.9.89 (2023-02-26)
-------------------
- Release: version 0.9.89 🚀 [hiddify]
- Release: version 0.89 🚀 [hiddify]
- Fix. [hiddify]
- Fix bug. [hiddify]


0.9.88 (2023-02-26)
-------------------
- Release: version 0.9.88 🚀 [hiddify]
- Add pyyaml. [hiddify]


0.9.87 (2023-02-26)
-------------------
- Release: version 0.9.87 🚀 [hiddify]
- Remove update db notif. [hiddify]


0.9.86 (2023-02-26)
-------------------
- Release: version 0.9.86 🚀 [hiddify]
- Fix auto update usage. [hiddify]
- Update db on init. [hiddify]


0.9.85 (2023-02-26)
-------------------
- Release: version 0.9.85 🚀 [hiddify]
- Fix update usage. [hiddify]


0.9.84 (2023-02-26)
-------------------
- Release: version 0.9.84 🚀 [hiddify]
- Fix null bug. [hiddify]


0.9.83 (2023-02-26)
-------------------
- Release: version 0.9.83 🚀 [hiddify]
- Update. [hiddify]
- Add chart for online user. [hiddify]
- Add online users. [hiddify]


0.9.82 (2023-02-26)
-------------------
- Release: version 0.9.82 🚀 [hiddify]
- Fix bad bug. [Hiddify]


0.9.81 (2023-02-26)
-------------------
- Release: version 0.9.81 🚀 [hiddify]
- Add tun mode in clash proxies. [hiddify]
- Not exist domain. [hiddify]


0.9.80 (2023-02-26)
-------------------
- Release: version 0.9.80 🚀 [hiddify]
- Update. [hiddify]
- Fix bug in import users. [hiddify]
- Update centeral panel layoutt. [hiddify]


0.9.79 (2023-02-26)
-------------------
- Release: version 0.9.79 🚀 [hiddify]
- Fix. [hiddify]


0.9.78 (2023-02-26)
-------------------
- Release: version 0.9.78 🚀 [hiddify]
- Fix. [hiddify]
- Update. [hiddify]


0.9.77 (2023-02-26)
-------------------
- Release: version 0.9.77 🚀 [hiddify]
- Update. [hiddify]


0.9.76 (2023-02-26)
-------------------
- Release: version 0.9.76 🚀 [hiddify]
- Fix change lang issue. [hiddify]


0.9.75 (2023-02-26)
-------------------
- Release: version 0.9.75 🚀 [hiddify]
- Fix backup. [hiddify]
- Update. [hiddify]


0.9.74 (2023-02-26)
-------------------
- Release: version 0.9.74 🚀 [hiddify]
- Fix. [hiddify]
- Update. [hiddify]


0.9.73 (2023-02-26)
-------------------
- Release: version 0.9.73 🚀 [hiddify]
- Fix. [hiddify]


0.9.72 (2023-02-26)
-------------------
- Release: version 0.9.72 🚀 [hiddify]
- Fix. [hiddify]


0.9.71 (2023-02-26)
-------------------
- Release: version 0.9.71 🚀 [hiddify]
- Fix update panel. [hiddify]


0.9.70 (2023-02-26)
-------------------
- Release: version 0.9.70 🚀 [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Fix updateusage. [hiddify]
- Fix. [hiddify]
- Update panel. [hiddify]
- Fix. [hiddify]
- Fix child. [hiddify]
- Fix db. [hiddify]
- Add config cli. [hiddify]
- Fix. [hiddify]
- Fix domains. [hiddify]
- Update. [hiddify]
- Updaet. [hiddify]
- Add unique id. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Add json. [hiddify]
- Update. [hiddify]
- Fix. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Add set config from cli. [hiddify]
- Fix all configs. [hiddify]
- Add parent panel. [hiddify]


0.9.66 (2023-02-25)
-------------------
- Release: version 0.9.66 🚀 [hiddify]
- Fix multi link. [hiddify]
- Merge branch 'main' of github.com:hiddify/HiddifyPanel. [hiddify]
- Update README.md. [Hiddify]


0.9.65 (2023-02-24)
-------------------
- Release: version 0.9.65 🚀 [hiddify]
- Fix restore and backup of domains. [hiddify]


0.9.64 (2023-02-23)
-------------------
- Release: version 0.9.64 🚀 [hiddify]
- Fix backup. [hiddify]


0.9.63 (2023-02-23)
-------------------
- Release: version 0.9.63 🚀 [hiddify]
- Fix backup. [hiddify]


0.9.62 (2023-02-22)
-------------------
- Release: version 0.9.62 🚀 [hiddify]
- Fix loop. [hiddify]


0.9.61 (2023-02-22)
-------------------
- Release: version 0.9.61 🚀 [hiddify]
- Fix. [hiddify]


0.9.60 (2023-02-22)
-------------------
- Release: version 0.9.60 🚀 [hiddify]
- Add hiddify desktop. [hiddify]
- Add ability to change proxy path. [hiddify]
- Add restore settings enable disable. [hiddify]
- Add more info about relay and fake. [hiddify]


0.9.59 (2023-02-22)
-------------------
- Release: version 0.9.59 🚀 [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]


0.9.58 (2023-02-22)
-------------------
- Release: version 0.9.58 🚀 [hiddify]
- Add autopep8. [hiddify]
- Adding domain specific configuration. [hiddify]
- Add reset after 30 days. [hiddify]
- Add version to home. [hiddify]


0.9.57 (2023-02-17)
-------------------
- Release: version 0.9.57 🚀 [hiddify]
- FIX. [hiddify]
- Release: version 0.9.56 🚀 [hiddify]
- Change  admin secret to lower case. [hiddify]
- Release: version 0.9.55 🚀 [hiddify]
- Update ios. [hiddify]


0.9.56 (2023-02-16)
-------------------
- Release: version 0.9.56 🚀 [hiddify]
- Add ios. [hiddify]


0.9.55 (2023-02-16)
-------------------
- Release: version 0.9.55 🚀 [hiddify]
- Fix stash link in ios. [hiddify]


0.9.54 (2023-02-16)
-------------------
- Release: version 0.9.54 🚀 [hiddify]
- Fix support box in mobile. [hiddify]


0.9.53 (2023-02-16)
-------------------
- Release: version 0.9.53 🚀 [hiddify]
- Add version in menu. [hiddify]


0.9.52 (2023-02-16)
-------------------
- Release: version 0.9.52 🚀 [hiddify]
- Add version to sidebar. [hiddify]


0.9.51 (2023-02-16)
-------------------
- Release: version 0.9.51 🚀 [hiddify]
- Fix layout. [hiddify]


0.9.50 (2023-02-16)
-------------------
- Release: version 0.9.50 🚀 [hiddify]
- Update. [hiddify]
- Notify domain change on backup. [hiddify]


0.9.49 (2023-02-16)
-------------------
- Release: version 0.9.49 🚀 [hiddify]
- Update. [hiddify]


0.9.47 (2023-02-16)
-------------------
- Release: version 0.9.47 🚀 [hiddify]
- Fix click. [hiddify]


0.9.46 (2023-02-16)
-------------------
- Release: version 0.9.46 🚀 [hiddify]
- Fix error. [hiddify]


0.9.45 (2023-02-16)
-------------------
- Release: version 0.9.45 🚀 [hiddify]
- Update. [hiddify]
- Fix not showing date in firefox. [hiddify]


0.9.44 (2023-02-16)
-------------------
- Release: version 0.9.44 🚀 [hiddify]
- Update. [hiddify]
- Fix error in change proxy apply. [hiddify]


0.9.43 (2023-02-16)
-------------------
- Release: version 0.9.43 🚀 [hiddify]
- Remove some dependencies. [hiddify]


0.9.42 (2023-02-16)
-------------------
- Release: version 0.9.42 🚀 [hiddify]
- Update. [hiddify]


0.9.41 (2023-02-16)
-------------------
- Release: version 0.9.41 🚀 [hiddify]
- Update. [hiddify]


0.9.40 (2023-02-15)
-------------------
- Release: version 0.9.40 🚀 [hiddify]
- Fix exception. [hiddify]


0.9.39 (2023-02-15)
-------------------
- Release: version 0.9.39 🚀 [hiddify]
- Add domain name to clash proxy. [hiddify]
- Allow ipv6. [hiddify]
- Update. [hiddify]
- Fix invalid domain names for decoy website. [hiddify]


0.9.38 (2023-02-15)
-------------------
- Release: version 0.9.38 🚀 [hiddify]
- Add hiddify proxy v0.11. [hiddify]


0.9.37 (2023-02-15)
-------------------
- Release: version 0.9.37 🚀 [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Release: version 0.9.36 🚀 [hiddify]


0.9.35 (2023-02-15)
-------------------
- Release: version 0.9.35 🚀 [hiddify]
- Add version. [hiddify]
- Add version in panel. [hiddify]


0.9.34 (2023-02-15)
-------------------
- Release: version 0.9.34 🚀 [hiddify]


0.9.33 (2023-02-15)
-------------------
- Release: version 0.9.33 🚀 [hiddify]
- Add hiddify android v 0.10. [hiddify]
- Add global client fingerprint. [hiddify]
- Fix ipv6. [hiddify]


0.9.31 (2023-02-15)
-------------------
- Release: version 0.9.31 🚀 [hiddify]
- Fix full install everytime. [hiddify]


0.9.30 (2023-02-15)
-------------------
- Release: version 0.9.30 🚀 [hiddify]
- Fix represntation of fake in user page. [hiddify]


0.9.29 (2023-02-15)
-------------------
- Release: version 0.9.29 🚀 [hiddify]
- Add fake domain. [hiddify]


0.9.28 (2023-02-15)
-------------------
- Release: version 0.9.28 🚀 [hiddify]
- Add fake domain. [hiddify]


0.9.27 (2023-02-15)
-------------------
- Release: version 0.9.27 🚀 [hiddify]
- Update. [hiddify]


0.9.26 (2023-02-14)
-------------------
- Release: version 0.9.26 🚀 [hiddify]
- Update. [hiddify]


0.9.25 (2023-02-14)
-------------------
- Release: version 0.9.25 🚀 [hiddify]
- Update. [hiddify]


0.9.24 (2023-02-14)
-------------------
- Release: version 0.9.24 🚀 [hiddify]


0.9.22 (2023-02-14)
-------------------
- Release: version 0.9.22 🚀 [hiddify]
- Fix. [hiddify]


0.9.21 (2023-02-14)
-------------------
- Release: version 0.9.21 🚀 [hiddify]
- Remove direct links in CDN. [hiddify]


0.9.20 (2023-02-14)
-------------------
- Release: version 0.9.20 🚀 [hiddify]
- Fix direct domain db. [hiddify]


0.9.19 (2023-02-14)
-------------------
- Release: version 0.9.19 🚀 [hiddify]
- Add ipv6 connections. [hiddify]


0.9.18 (2023-02-14)
-------------------
- Release: version 0.9.18 🚀 [hiddify]
- Update multi domain. [hiddify]


0.9.17 (2023-02-14)
-------------------
- Release: version 0.9.17 🚀 [hiddify]
- Update. [hiddify]


0.9.15 (2023-02-14)
-------------------
- Release: version 0.9.15 🚀 [hiddify]
- Add multi link. [hiddify]


0.9.14 (2023-02-14)
-------------------
- Release: version 0.9.14 🚀 [hiddify]
- Update. [hiddify]


0.9.13 (2023-02-14)
-------------------
- Release: version 0.9.13 🚀 [hiddify]
- Fix. [hiddify]


0.9.12 (2023-02-13)
-------------------
- Release: version 0.9.12 🚀 [hiddify]
- Add fingerprint in share link. [hiddify]


0.9.11 (2023-02-13)
-------------------
- Release: version 0.9.11 🚀 [hiddify]
- Remove need for apply for adding a user. [hiddify]
- Update. [hiddify]


0.9.10 (2023-02-10)
-------------------
- Release: version 0.9.10 🚀 [hiddify]
- Add grpc direct. [hiddify]
- Add relay mode. [hiddify]


0.9.9 (2023-02-09)
------------------
- Release: version 0.9.9 🚀 [hiddify]
- Update quick setup. [hiddify]
- Update. [hiddify]
- Update. [hiddify]


0.9.8 (2023-02-09)
------------------
- Release: version 0.9.8 🚀 [hiddify]
- Update. [hiddify]


0.9.7 (2023-02-09)
------------------
- Release: version 0.9.7 🚀 [hiddify]
- Fix translation. [hiddify]


0.9.6 (2023-02-09)
------------------
- Release: version 0.9.6 🚀 [hiddify]
- Add specified ip for cdn hosts. [hiddify]
- Add forced ip. [hiddify]


0.9.5 (2023-02-09)
------------------
- Release: version 0.9.5 🚀 [hiddify]
- Remove. [hiddify]


0.9.4 (2023-02-09)
------------------
- Release: version 0.9.4 🚀 [hiddify]
- Update. [hiddify]


0.9.3 (2023-02-09)
------------------
- Release: version 0.9.3 🚀 [hiddify]
- Update. [hiddify]
- Add fingerprint. [hiddify]
- Add fingerprint. [hiddify]


0.9.2 (2023-02-09)
------------------
- Release: version 0.9.2 🚀 [hiddify]
- Fix xtls vision. [hiddify]
- Remove trojan and add vless. [hiddify]
- Remove xtls direct. [hiddify]


0.9.1 (2023-02-09)
------------------
- Release: version 0.9.1 🚀 [hiddify]
- Fix layout. [hiddify]
- Update. [hiddify]
- Update link. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Add link from domain to admin page. [hiddify]
- Update ui. [hiddify]
- Ram update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update ux and ui in admin. [hiddify]
- Update. [hiddify]
- Fix emergency access. [hiddify]
- Fix. [hiddify]
- Organizing db. [hiddify]
- Fix error csrf. [hiddify]
- Fix. [hiddify]
- Update. [hiddify]
- Remove verification. [hiddify]
- Fix setting admin. [hiddify]
- Fix. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Fix caps domain. [hiddify]
- Fix v2ray. [hiddify]
- Remove csrf. [hiddify]
- Fix not creating same uuid in restore. [hiddify]
- Fix alpn. [hiddify]
- Remove alpn for h2 in links. [hiddify]
- Fix faketls. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update link_maker.py. [Hiddify]
- Update link_maker.py. [Hiddify]
- Update. [hiddify]
- Fix. [hiddify]
- Update icon. [hiddify]
- Update usage. [hiddify]
- Add domain to infoname. [hiddify]
- Fix bug. [hiddify]
- Fix domain fronting. [hiddify]
- Showing alert before leaving apply settings page. [hiddify]
- Update. [hiddify]
- Lang update. [hiddify]
- Update. [hiddify]
- Fix. [hiddify]
- Fix. [hiddify]
- Fix fake. [hiddify]
- Update. [hiddify]
- Fix bug. [hiddify]
- Add temporary link. [hiddify]
- Fix bug. [hiddify]
- Fix. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Add an option to select between monthly and total. [hiddify]
- Update translation. [hiddify]
- Add some configs. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update translation. [hiddify]
- Add backup and restore. [hiddify]
- Fix support link. [hiddify]
- Fix admin link. [hiddify]
- Update. [hiddify]
- Fix bug in domain. [hiddify]
- Update. [hiddify]
- Fix ip removed. [hiddify]
- Update lang. [hiddify]
- Validate domain. [hiddify]
- Fix domian. [hiddify]
- Add user error message. [hiddify]
- Fix bug. [hiddify]
- Update. [hiddify]
- Fix. [hiddify]
- Add first setup. [hiddify]
- Fix init bug. [hiddify]
- Update. [hiddify]
- Update. [hiddify]


0.9.0 (2023-02-04)
------------------
- Release: version 0.9.0 🚀 [hiddify]
- Update translations. [hiddify]
- Update. [hiddify]
- Add donation link. [hiddify]
- Add apply config for users. [hiddify]
- Update. [hiddify]
- Add branding link. [hiddify]
- Update. [hiddify]
- Update ui. [hiddify]
- Full. [hiddify]
- Update. [hiddify]
- Add full install option. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update telegram lib. [hiddify]
- Quicksetup lang. [hiddify]
- Add admin language. [hiddify]
- Update. [hiddify]
- Update admin lang. [hiddify]
- Fix delete user error. [hiddify]
- Fix. [hiddify]
- Update. [hiddify]
- Fix update db version. [hiddify]
- Update db. [hiddify]
- Add log for initdb. [hiddify]
- Update. [hiddify]
- Fixed. [hiddify]
- Fix user. [hiddify]
- Update translations. [hiddify]
- Update. [hiddify]
- Charts info. [hiddify]
- Release: version 0.8.5 🚀 [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Add telegram lib. [hiddify]
- Fix float. [hiddify]
- Fix sqlalchemy. [hiddify]
- Update. [hiddify]
- Remove some logs. [hiddify]
- Update. [hiddify]
- Add temporary rule for firewall to access. [hiddify]
- Random port. [hiddify]
- Fix not reset the usage. [hiddify]
- Add icon, add temp port update message. [hiddify]
- Update remove incomplete configs. [hiddify]
- Small fix. [hiddify]
- Fix user remove error and more checkings. [hiddify]
- Fix link. [hiddify]
- Fix link. [hiddify]
- Add api. [hiddify]
- Fix usage shown. [hiddify]
- Update. [hiddify]
- Add log finish message. [hiddify]
- Add default user link info message for quick setup. [hiddify]


0.8.6 (2023-02-03)
------------------
- Release: version 0.8.6 🚀 [hiddify]
- Update. [hiddify]


0.8.5 (2023-02-03)
------------------
- Release: version 0.8.5 🚀 [hiddify]
- Fix grpc link. [hiddify]
- Fix normal clash link. [hiddify]
- Fix bug in versioning. [hiddify]
- Release: version 0.8.4 🚀 [hiddify]


0.8.4 (2023-02-03)
------------------
- Fix bugs. [hiddify]
- Release: version 0.8.3 🚀 [hiddify]


0.8.3 (2023-02-03)
------------------
- Fix uuid. [hiddify]
- Release: version 0.8.2 🚀 [hiddify]


0.8.2 (2023-02-03)
------------------
- Fix vmess links. [hiddify]
- Fix grpc. [hiddify]
- Fix ios links. [hiddify]
- Fix bug in telegram and not showing all emails. [hiddify]
- Release: version 0.8.1 🚀 [hiddify]


0.8.1 (2023-02-02)
------------------
- Fix bug in time. [hiddify]
- Release: version 0.8.0 🚀 [hiddify]


0.8.0 (2023-02-02)
------------------
- Update. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Update ui. [hiddify]
- Update style. [hiddify]
- Update style. [hiddify]
- Update. [hiddify]
- Update http-opts. [hiddify]
- Fix. [hiddify]
- Update link maker. [hiddify]
- Fix port bug. [hiddify]
- Update. [hiddify]
- Fix bug. [hiddify]
- Remove vless and xtls and shadowtls for normal clash. [hiddify]
- Release: version 0.7.0 🚀 [hiddify]


0.7.0 (2023-02-02)
------------------
- Update. [hiddify]
- Update clashlinks. [hiddify]
- Fix update usage. [hiddify]
- Release: version 0.6.0 🚀 [hiddify]


0.6.0 (2023-02-02)
------------------
- Update. [hiddify]
- New translations. [hiddify]
- Fix. [hiddify]
- Fix bug. [hiddify]
- Release: version 0.5.0 🚀 [hiddify]


0.5.0 (2023-02-02)
------------------
- Update translation. [hiddify]
- Add auto update translations. [hiddify]
- Fix import. [hiddify]
- Add mo files. [hiddify]
- Trying to fix translation issues. [hiddify]
- Update translations. [hiddify]
- Update. [hiddify]
- Add translations. [hiddify]
- Update. [hiddify]
- Add link. [hiddify]
- Add chinese lang. [hiddify]
- Add auto translate. [hiddify]
- Fix. [hiddify]
- Fix translations. [hiddify]
- Remove changing proxy path. [hiddify]
- Add success notification to domain. [hiddify]
- Remove category from config. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Fix decoy site to domain. [hiddify]
- Update order. [hiddify]
- Update. [hiddify]
- Reorgnizing. [hiddify]
- Fix cli bug. [hiddify]
- Update. [hiddify]
- Update. [hiddify]
- Release: version 0.4.0 🚀 [hiddify]


0.4.0 (2023-02-01)
------------------
- Update FUNDING.yml. [Hiddify]
- Update. [hiddify]
- Add selectable proxies. [hiddify]
- Selectable proxy. [hiddify]
- Update. [hiddify]
- Latest update. [hiddify]
- Update. [hiddify]
- Adding tuic, shadowtls, ssr, ui improvment. [hiddify]
- Update user ui. [hiddify]
- Update. [hiddify]
- Release: version 0.3.0 🚀 [hiddify]


0.3.0 (2023-01-22)
------------------
- Include static files. [hiddify]
- Update cli. [hiddify]
- Fix prob. [hiddify]
- Release: version 0.2.0 🚀 [hiddify]


0.2.0 (2023-01-22)
------------------
- Release: version 0.0.2 🚀 [hiddify]


0.0.2 (2023-01-22)
------------------
- Update. [hiddify]
- Update. [hiddify]
- Update and reset automatically the usage. [hiddify]
- Release: version 0.0.1 🚀 [hiddify]


0.0.1 (2023-01-21)
------------------
- Remove windows and mac. [hiddify]
- Update. [hiddify]
- Add update storage. [hiddify]
- First working version. [hiddify]
- Create default db. [hiddify]
- Update to bootstrap 5. [hiddify]
- ✅ Ready to clone and code. [hiddify]
- Initial commit. [Hiddify]


